pub struct AuthCertUnverified {
body: AuthCert,
pub sigs: SignaturesData<AuthCertUnverified>,
}Expand description
Signed (unverified) form of AuthCert
Embodies:
AuthCert: document bodyAuthCertSignatures: signatures
If this type was parsed from a document text, the signatures have not yet been verified.
Use a .verify_... method to obtain useable, verified, contents.
Fields
body: AuthCertThe actual body
sigs: SignaturesData<AuthCertUnverified>Signatures
Implementations
Sourceimpl AuthCertUnverified
impl AuthCertUnverified
Sourcepub fn verify(
self,
v3idents: &[RsaIdentity],
pre_tolerance: Duration,
post_tolerance: Duration,
now: SystemTime,
) -> StdResult<AuthCert, VerifyFailed>
pub fn verify( self, v3idents: &[RsaIdentity], pre_tolerance: Duration, post_tolerance: Duration, now: SystemTime, ) -> StdResult<AuthCert, VerifyFailed>
Verifies the signature of a AuthCert
Algorithm
- Check whether this comes from a valid authority in
v3idents. - Check whether the timestamps are valid (± tolerance).
- Check whether the fingerprint and long-term identity key match.
- Check the cross-certificate (proof-of-ownership of signing key).
- Check the outer certificate (proof-of-ownership of identity key).
TODO: Replace pre_tolerance and post_tolerance with
tor_dircommon::config::DirTolerance which is not possible at the
moment due to a circular dependency of tor-dircommon depending
upon tor-netdoc.
TODO: Consider whether to try to deduplicate this signature checking
somehow, wrt to UncheckedAuthCert.
Sourcepub fn verify_selfcert(
self,
now: SystemTime,
) -> StdResult<AuthCert, VerifyFailed>
pub fn verify_selfcert( self, now: SystemTime, ) -> StdResult<AuthCert, VerifyFailed>
Verify the signatures (and check validity times)
The pre and post tolerance (time check allowances) used are both zero.
Security considerations
The caller must check that the KP_auth_id is correct/relevant.